Changelog
---------


0.4.0 (2017.-06-18)
~~~~~~~~~~~~~~~~~~~

Version 0.4.0.

* Embedding backward
* Momentum
* NesterovMomentum
* Adagrad
* RMSprop
* Adadelta
* Adam
* Adamax



0.3.0 (2017-06-15)
~~~~~~~~~~~~~~~~~~

Version 0.3.0.

* Add chatbot application.
* Add more examples.
* Support LSTM.
* Support GRU.


0.2.5 (2017-05-30)
~~~~~~~~~~~~~~~~~~

Version 0.2.5.

Add almost all test.



0.2 (2017-05-10)
~~~~~~~~~~~~~~~~

Second release.

Support Layers:

* Batch Normalization Layer
* Embedding Layer
* MeanPooling Layer
* Flatten Layer

Support Activations:

* SymmetricElliot
* LReLU
* SoftPlus
* SoftSign

Support Initializations:

* HeNormal
* HeUniform
* Orthogonal

Add more tutorials.

Add more API comments.



0.1 (2017-04-11)
~~~~~~~~~~~~~~~~

First release.

Support layers:

* Dense (perceptron) Layer
* Softmax Layer
* Dropout Layer
* Convolution Layer
* MaxPooling Layer
* SimpleRNN Layer


Support Activations:

* Sigmoid
* Tanh
* ReLU
* Softmax
* Elliot


Support Initializations:

* Uniform
* Normal
* LecunUniform
* GlorotUniform
* GlorotNormal


Support Objectives:

* MeanSquaredError
* HellingerDistance
* BinaryCrossEntropy
* SoftmaxCategoricalCrossEntropy


Support Optimizers:

* SGD

